module Fenix
  class Settings
    # @since 1.0.0
    # @api public
    def initialize(file = nil)
      @settings = {}
    end

    ####
    # Returns the provided configuration option
    ####
    #
    # @param [Symbol] key
    #
    # @example
    #   settings[:compress_assets]
    #   # => true
    #
    #   settings.compress_assets
    #   # => true
    #
    # @since 1.0.0
    # @api public
    def [](key)
      @settings[key.to_sym]
    end

    ####
    # Sets the provided configuration option
    ####
    #
    # @param [Symbol] key
    # @param value
    #
    # @example
    #   settings[:compress_assets] = true
    #   settings.compress_assets = true
    #
    # @return [value]
    # @since 1.0.0
    # @api public
    def []=(key, value)
      @settings[key.to_sym] = value
    end
  end # Settings
end # Fenix